@@ -13,11 +13,14 @@
 ##############################################################################
 """Zope Application Server Generations
 
-$Id: __init__.py 70794 2006-10-19 04:29:42Z baijum $
+$Id: __init__.py 98892 2009-04-05 19:43:33Z icemac $
 """
 __docformat__ = "reStructuredText"
+
 from zope.app.generations.generations import SchemaManager
-from zope.app.publication.zopepublication import ZopePublication
+# BBB import
+from zope.app.generations.utility import getRootFolder
+
 
 key = 'zope.app.zopeappgenerations'
 
@@ -26,7 +29,3 @@ ZopeAppSchemaManager = SchemaManager(
     minimum_generation=1,
     generation=5,
     package_name=key)
-
-
-def getRootFolder(context):
-    return context.connection.root().get(ZopePublication.root_name, None)
